@@ -4,14 +4,18 @@ from dataclasses import (
 from redshift_client.data_type.core import (
     DataType,
 )
+from redshift_client.sql_client.core import (
+    PrimitiveVal,
+)
 
 
 @dataclass(frozen=True)
 class ColumnId:
-    _name: str
+    name: str
 
 
 @dataclass(frozen=True)
 class Column:
     data_type: DataType
     nullable: bool
+    default: PrimitiveVal
