@@ -58,7 +58,7 @@ class SchemaClient:
             new_query(stm), None
         ) + self._db_client.fetch_all().map(
             lambda i: frozenset(
-                SchemaId(to_primitive(e[0], str).unwrap()) for e in i
+                SchemaId(to_primitive(e.data[0], str).unwrap()) for e in i
             )
         )
 
@@ -73,7 +73,8 @@ class SchemaClient:
             new_query(stm), FrozenDict({"schema_name": schema.name})
         ) + self._db_client.fetch_all().map(
             lambda i: frozenset(
-                TableId(schema, to_primitive(e[0], str).unwrap()) for e in i
+                TableId(schema, to_primitive(e.data[0], str).unwrap())
+                for e in i
             )
         )
 
@@ -86,8 +87,8 @@ class SchemaClient:
         stm = " ".join(_stm)
         return self._db_client.execute(
             new_query(stm), FrozenDict({"schema_name": schema.name})
-        ) + self._db_client.fetch_one().map(
-            lambda i: _assert_bool(i[0])
+        ) + self._db_client.fetch_one().map(lambda x: x.value_or(None)).map(
+            lambda i: _assert_bool(i.data[0])
             if i is not None
             else raise_exception(TypeError("Expected not None"))
         )
